Welcome to pydiffmap
====================

This is the home of the documentation for pyDiffMap, an open-source project to develop a robust and accessible diffusion map code for public use.  Code can be found on our `github page`__.  Our documentation is currently under construction, please bear with us.

.. _github: https://github.com/DiffusionMapsAcademics/pyDiffMap/

__ github_




========
Contents
========

.. toctree::
   :maxdepth: 2

   readme
   installation
   theory
   usage
   jupyter notebook tutorials/index
   reference/index
   contributing
   authors
   acknowledgements
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
